<!-- markdownlint-disable MD041 -->
<!-- Filling out this template is mandatory -->

<!-- =========================== -->
<!-- DO NOT EDIT ABOVE THIS LINE -->
<!-- =========================== -->

## Detailed Description

<!--
	Explain the details and and possible context for this change.

	* Is it a new feature?
	* What problem(s) does it solve?
	* How does this solve them?
	* Are there any known or expected side-effects to this change?

	Please provide enough information so that others who may not be as deeply familiar
	with the specific changes you're working on can review the pull request.

	The commit messages to this are considered supplementary and not a replacement for
	the description here.

	Delete this comment itself and replace it with your description.
-->

# Pull Request Checklist
<!-- These are *required* -->

* [ ] This is an API breaking change. <!-- Check this box only if this is a breaking change -->
* [ ] I agree to follow the Torii Boards [Code Of Conduct].
* [ ] I've read and understand the [Contribution Guidelines] and [AI Usage Policy] for Torii Boards and agree to follow them.
* [ ] I've tested this to the best of my ability.
* [ ] I've documented the change to the best my ability.

## Relevant Issues/Pull Requests/Discussions

<!--
	Delete this comment and ink to any relevant issues, pull requests, or discussions here,
	if there are no relevant issues, pull requests, or discussions, then delete this comment
	and the heading above.

	Some examples:

		If it fixes an issue:

			- fixes #XXXX

		If it depends on another PR:

			- needs #XXXX

		If it references a discussion:

			- [discussions/XXXXX](https://github.com/shrine-maiden-heavy-industries/torii-boards/discussions/XXXXX)
-->

<!-- =========================== -->
<!-- DO NOT EDIT BELOW THIS LINE -->
<!-- =========================== -->

[Code Of Conduct]: https://github.com/shrine-maiden-heavy-industries/torii-boards/blob/main/CODE_OF_CONDUCT.md
[Contribution Guidelines]: https://github.com/shrine-maiden-heavy-industries/torii-boards/blob/main/CONTRIBUTING.md
[AI Usage Policy]: https://github.com/shrine-maiden-heavy-industries/torii-boards/blob/main/CONTRIBUTING.md#ai-usage-policy
